@@ -1,4 +1,4 @@
-# Copyright (C) 2017  Spencer Aiello
+# Copyright (C) 2017-2018  Spencer Aiello
 #
 # This file is part of JuniperKernel.
 #
@@ -33,6 +33,6 @@
 #' @references \url{http://jupyter-client.readthedocs.io/en/latest/messaging.html#history}
 #' @export
 history_request <- function(request_msg) {
-  message("unimpl")
-  list(msg_type = "history_reply", content = list())
+  content <- list(history=list(list(0,0,"")))
+  list(msg_type = "history_reply", content=content)
 }
